# mypy-boto3-schemas

[![PyPI - mypy-boto3-schemas](https://img.shields.io/pypi/v/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Schemas 1.15.4](https://boto3.amazonaws.com/v1/documentation/api/1.15.4/reference/services/schemas.html#Schemas) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-schemas](#mypy-boto3-schemas)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Schemas` service.

```bash
python -m pip install boto3-stubs[schemas]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[schemas]` in your environment: `python -m pip install 'boto3-stubs[schemas]'`

Both type checking and auto-complete should work for `Schemas` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[schemas]` in your environment: `python -m pip install 'boto3-stubs[schemas]'`

Both type checking and auto-complete should work for `Schemas` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[schemas]` in your environment: `python -m pip install 'boto3-stubs[schemas]'`
- Run `mypy` as usual

Type checking should work for `Schemas` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[schemas]` in your environment: `python -m pip install 'boto3-stubs[schemas]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Schemas` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`SchemasClient` provides annotations for `boto3.client("schemas")`.

```python
import boto3

from mypy_boto3_schemas import SchemasClient

client: SchemasClient = boto3.client("schemas")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SchemasClient = session.client("schemas")
```

### Paginators annotations

`mypy_boto3_schemas.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.paginator import (
    ListDiscoverersPaginator,
    ListRegistriesPaginator,
    ListSchemasPaginator,
    ListSchemaVersionsPaginator,
    SearchSchemasPaginator,
)

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_discoverers_paginator: ListDiscoverersPaginator = client.get_paginator("list_discoverers")
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
search_schemas_paginator: SearchSchemasPaginator = client.get_paginator("search_schemas")
```


### Waiters annotations

`mypy_boto3_schemas.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.waiter import CodeBindingExistsWaiter

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
code_binding_exists_waiter: CodeBindingExistsWaiter = client.get_waiter("code_binding_exists")
```





### Typed dictionations

`mypy_boto3_schemas.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_schemas.type_defs import (
    CreateDiscovererResponseTypeDef,
    CreateRegistryResponseTypeDef,
    CreateSchemaResponseTypeDef,
    DescribeCodeBindingResponseTypeDef,
    DescribeDiscovererResponseTypeDef,
    DescribeRegistryResponseTypeDef,
    DescribeSchemaResponseTypeDef,
    DiscovererSummaryTypeDef,
    GetCodeBindingSourceResponseTypeDef,
    GetDiscoveredSchemaResponseTypeDef,
    GetResourcePolicyResponseTypeDef,
    ListDiscoverersResponseTypeDef,
    ListRegistriesResponseTypeDef,
    ListSchemasResponseTypeDef,
    ListSchemaVersionsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutCodeBindingResponseTypeDef,
    PutResourcePolicyResponseTypeDef,
    RegistrySummaryTypeDef,
    SchemaSummaryTypeDef,
    SchemaVersionSummaryTypeDef,
    SearchSchemasResponseTypeDef,
    SearchSchemaSummaryTypeDef,
    SearchSchemaVersionSummaryTypeDef,
    StartDiscovererResponseTypeDef,
    StopDiscovererResponseTypeDef,
    UpdateDiscovererResponseTypeDef,
    UpdateRegistryResponseTypeDef,
    UpdateSchemaResponseTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> DiscovererSummaryTypeDef:
    return {
      ...
    }
```
